@@ -5,9 +5,9 @@ check() {
     # If our prerequisites are not met, fail anyways.
     require_binaries mount.cifs || return 1
 
-    [[ $hostonly ]] || [[ $mount_needs ]] && {
+    [[ $hostonly_mode == "strict" ]] || [[ $mount_needs ]] && {
         for fs in "${host_fs_types[@]}"; do
-            [[ "$fs" == "cifs" ]] && return 0
+            [[ $fs == "cifs" ]] && return 0
         done
         return 255
     }
@@ -34,15 +34,18 @@ installkernel() {
 
 # called by dracut
 install() {
-    local _i
     local _nsslibs
     inst_multiple -o mount.cifs
-    inst_multiple /etc/services /etc/nsswitch.conf /etc/protocols
+    inst_multiple -o /etc/services /etc/nsswitch.conf /etc/protocols
+    inst_multiple -o /usr/etc/services /usr/etc/nsswitch.conf /usr/etc/protocols
 
     inst_libdir_file 'libcap-ng.so*'
 
-    _nsslibs=$(sed -e '/^#/d' -e 's/^.*://' -e 's/\[NOTFOUND=return\]//' $dracutsysrootdir/etc/nsswitch.conf \
-        |  tr -s '[:space:]' '\n' | sort -u | tr -s '[:space:]' '|')
+    _nsslibs=$(
+        cat "$dracutsysrootdir"/{,usr/}etc/nsswitch.conf 2> /dev/null \
+            | sed -e '/^#/d' -e 's/^.*://' -e 's/\[NOTFOUND=return\]//' \
+            | tr -s '[:space:]' '\n' | sort -u | tr -s '[:space:]' '|'
+    )
     _nsslibs=${_nsslibs#|}
     _nsslibs=${_nsslibs%|}
 
